// Copyright 2023 schukai GmbH
// SPDX-License-Identifier: AGPL-3.0

package commands

import (
	"github.com/jessevdk/go-flags"
	"gitlab.schukai.com/oss/utilities/documentation-manager/document"
	"gitlab.schukai.com/oss/utilities/documentation-manager/environment"
	"gitlab.schukai.com/oss/utilities/documentation-manager/translations"
	"time"
)

const documentAddSymbol = "document-add"

// language: md
const newDocumentTemplate = `
---
# Document title
Title: New Document

# keywords mainly used for searching
Keywords:
  - documentation

References:
	- https://www.example.com/

# Abbreviation of the document
Abbreviation: 

# First and last name of the authors as a list
Authors: 
  - null

Version: 1.0

Created: %%CREATED%%
Last Update: %%CREATED%%


Language: en

# Which level of the document is this?
Level: 1

...

## {{ .Title }}

Lorem ipsum dolor sit amet, consectetur adipiscing elit.
`

func init() {

	h := environment.Handler{
		Init:    initDocumentAdd,
		Execute: runDocumentAdd,
	}

	environment.Handlers.Executor[documentAddSymbol] = h

}

type DocumentAddDefinition struct {
	Template   string `long:"template" short:"t"`
	Positional struct {
		Name []string `positional-arg-name:"name" required:"yes" positional:"yes"`
	} `positional-args:"yes" required:"yes"`
}

func initDocumentAdd(command *flags.Command) {
	const text = "Adds a new document"
	command.ShortDescription = translations.T.Sprintf(text)
	command.LongDescription = translations.T.Sprintf(text)

	for _, opt := range command.Options() {
		switch opt.LongName {
		case "template":
			opt.Description = translations.T.Sprintf("template for the new document")
		}
	}

	for _, arg := range command.Args() {
		switch arg.Name {
		case "name":
			arg.Description = translations.T.Sprintf("file names of the new documents, separated by spaces")
		}

	}

}

func runDocumentAdd(command *flags.Command) {

	names := definition.Document.Add.Positional.Name

	if len(names) == 0 {
		environment.ExitWithError(1, "no document name given")
	}

	root := environment.State.GetDocumentPath(definition.Document.SourcePath)
	template := environment.State.GetDocumentTemplate(definition.Document.Add.Template)

	date := time.Now().Format(environment.State.GetDocumentDateFormat(definition.Document.DateFormat))

	if template == "" {
		template = newDocumentTemplate
	}

	for _, name := range names {
		document.CreateNewDocument(name, root, template, date)
	}

}
